@@ -18,12 +18,12 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'CFLAGS': '-fno-strict-aliasing -OPT:Olimit=0 -O2 -pipe -DNDEBUG -O2 -pipe   -fPIC',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' '--srcdir=/usr/obj/ports/Python-2.7.14/Python-2.7.14' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
+ 'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' '--srcdir=/usr/obj/ports/Python-2.7.15/Python-2.7.15' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python2.7',
  'COREPYTHONPATH': ':plat-openbsd6:lib-tk:lib-old',
- 'COVERAGE_INFO': '/usr/obj/ports/Python-2.7.14/Python-2.7.14/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/ports/Python-2.7.14/Python-2.7.14/lcov-report',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-2.7.15/Python-2.7.15/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-2.7.15/Python-2.7.15/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -I/usr/local/include',
  'CXX': 'c++ -pthread',
@@ -87,12 +87,21 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
+ 'HAVE_CRYPT_H': 0,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 0,
+ 'HAVE_CURSES_FILTER': 1,
  'HAVE_CURSES_H': 1,
+ 'HAVE_CURSES_HAS_KEY': 1,
+ 'HAVE_CURSES_IMMEDOK': 1,
+ 'HAVE_CURSES_IS_PAD': 0,
  'HAVE_CURSES_IS_TERM_RESIZED': 1,
  'HAVE_CURSES_RESIZETERM': 1,
  'HAVE_CURSES_RESIZE_TERM': 1,
+ 'HAVE_CURSES_SYNCOK': 1,
+ 'HAVE_CURSES_TYPEAHEAD': 1,
+ 'HAVE_CURSES_USE_ENV': 1,
+ 'HAVE_CURSES_WCHGAT': 1,
  'HAVE_DECL_ISFINITE': 1,
  'HAVE_DECL_ISINF': 1,
  'HAVE_DECL_ISNAN': 1,
@@ -176,7 +185,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 1,
+ 'HAVE_LARGEFILE_SUPPORT': 0,
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
@@ -306,6 +315,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SYS_SOCKET_H': 1,
  'HAVE_SYS_STATVFS_H': 1,
  'HAVE_SYS_STAT_H': 1,
+ 'HAVE_SYS_SYSMACROS_H': 0,
  'HAVE_SYS_TERMIO_H': 0,
  'HAVE_SYS_TIMES_H': 1,
  'HAVE_SYS_TIME_H': 1,
@@ -347,16 +357,16 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'arm-unknown-openbsd6.3',
+ 'HOST_GNU_TYPE': 'aarch64-unknown-openbsd6.4',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include /usr/local/include/python2.7 /usr/local/include/python2.7',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python2.7',
- 'INSTALL': '/usr/obj/ports/Python-2.7.14/bin/install -c',
- 'INSTALL_DATA': '/usr/obj/ports/Python-2.7.14/bin/install -c  -m 644',
- 'INSTALL_PROGRAM': '/usr/obj/ports/Python-2.7.14/bin/install -c -s  -m 755',
- 'INSTALL_SCRIPT': '/usr/obj/ports/Python-2.7.14/bin/install -c  -m 755',
- 'INSTALL_SHARED': '/usr/obj/ports/Python-2.7.14/bin/install -c -m 555',
+ 'INSTALL': '/usr/obj/ports/Python-2.7.15/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-2.7.15/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-2.7.15/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-2.7.15/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-2.7.15/bin/install -c -m 555',
  'INSTSONAME': 'libpython2.7.so.0.0',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
  'LDFLAGS': '-L/usr/local/lib/',
@@ -455,7 +465,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.14/Python-2.7.14',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.15/Python-2.7.15',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -469,17 +479,17 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 8,
+ 'SIZEOF_LONG': 8,
+ 'SIZEOF_LONG_DOUBLE': 16,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
- 'SIZEOF_PTHREAD_T': 4,
+ 'SIZEOF_PTHREAD_T': 8,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 4,
+ 'SIZEOF_SIZE_T': 8,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 4,
- 'SIZEOF_VOID_P': 4,
+ 'SIZEOF_UINTPTR_T': 8,
+ 'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SO': '.so',
@@ -498,7 +508,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.14/Python-2.7.14 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.15/Python-2.7.15 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -523,11 +533,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-2.7.14/Python-2.7.14',
- 'abs_srcdir': '/usr/obj/ports/Python-2.7.14/Python-2.7.14',
- 'build': 'arm-unknown-openbsd6.3',
+ 'abs_builddir': '/usr/obj/ports/Python-2.7.15/Python-2.7.15',
+ 'abs_srcdir': '/usr/obj/ports/Python-2.7.15/Python-2.7.15',
+ 'build': 'aarch64-unknown-openbsd6.4',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
- 'host': 'arm-unknown-openbsd6.3',
+ 'host': 'aarch64-unknown-openbsd6.4',
  'prefix': '/usr/local',
  'srcdir': '.'}
